QuestionWidget class

Constructors

QuestionWidget({required Widget widget, required GlobalKey<State<StatefulWidget>> key, required Color color, String? rightAnswerKey})

Properties

color → Color
color of border
final
hashCode → int
The hash code for this object.
no setterinherited
key → GlobalKey<State<StatefulWidget>>
global key for question
final
rightAnswerKey ↔ String?
right answer key
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → Widget
pass widget as a question
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited